summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--common/ChangeLog4
-rw-r--r--common/strsep.c31
2 files changed, 21 insertions, 14 deletions
diff --git a/common/ChangeLog b/common/ChangeLog
index 9224055df..3a3d02d8e 100644
--- a/common/ChangeLog
+++ b/common/ChangeLog
@@ -1,3 +1,7 @@
+2004-12-03 Werner Koch <wk@g10code.com>
+
+ * strsep.c: Fixed copyright comments.
+
2004-11-26 Werner Koch <wk@g10code.com>
* simple-gettext.c: New taken from gnupg 1.3.x
diff --git a/common/strsep.c b/common/strsep.c
index af3f02e07..dd01a826f 100644
--- a/common/strsep.c
+++ b/common/strsep.c
@@ -1,31 +1,34 @@
/* strsep.c - Replacement for strsep().
- * Copyright (C) 2002 Free Software Foundation, Inc.
+ * Copyright (C) 1992, 1993, 1996, 1997, 1998, 1999,
+ * 2004 Free Software Foundation, Inc.
*
- * This file is part of GnuPG.
+ * This file is part of the GNU C Library.
*
- * GnuPG is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * The GNU C Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
*
- * GnuPG is distributed in the hope that it will be useful,
+ * The GNU C Library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
*/
+/* Code taken from glibc-2.3.2/sysdeps/generic/strsep.c and slightly
+ modified for use with GnuPG. */
+
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <stdio.h>
#include <string.h>
-/* Code taken from glibc-2.2.1/sysdeps/generic/strsep.c */
-#warning need to get the correct copyright years from glibc
char *
strsep (char **stringp, const char *delim)
{
@@ -1,31 +1,34 @@
* but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
*
@@ -1,31 +1,34 @@
*
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the GNU C Library; if not, write to the Free
+ * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+ * 02111-1307 USA.
*/